'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var umi = require('@metaplex-foundation/umi');
var errors = require('./errors.cjs');

function publicKey(options = {}) {
  return {
    description: options.description ?? 'publicKey',
    fixedSize: 32,
    maxSize: 32,
    serialize: value => umi.publicKey(value).bytes,
    deserialize: (bytes, offset = 0) => {
      if (bytes.slice(offset).length === 0) {
        throw new errors.DeserializingEmptyBufferError('publicKey');
      }
      const pubkeyBytes = bytes.slice(offset, offset + 32);
      if (pubkeyBytes.length < 32) {
        throw new errors.DataViewSerializerError(`Serializer [publicKey] expected 32 bytes, got ${pubkeyBytes.length}.`);
      }
      return [umi.publicKey(pubkeyBytes), offset + 32];
    }
  };
}

exports.publicKey = publicKey;
//# sourceMappingURL=pubkey.cjs.map
