import { publicKey as publicKey$1 } from '@metaplex-foundation/umi';
import { DeserializingEmptyBufferError, DataViewSerializerError } from './errors.mjs';

function publicKey(options = {}) {
  return {
    description: options.description ?? 'publicKey',
    fixedSize: 32,
    maxSize: 32,
    serialize: value => publicKey$1(value).bytes,
    deserialize: (bytes, offset = 0) => {
      if (bytes.slice(offset).length === 0) {
        throw new DeserializingEmptyBufferError('publicKey');
      }
      const pubkeyBytes = bytes.slice(offset, offset + 32);
      if (pubkeyBytes.length < 32) {
        throw new DataViewSerializerError(`Serializer [publicKey] expected 32 bytes, got ${pubkeyBytes.length}.`);
      }
      return [publicKey$1(pubkeyBytes), offset + 32];
    }
  };
}

export { publicKey };
//# sourceMappingURL=pubkey.mjs.map
